import { ComponentFixture, TestBed } from '@angular/core/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { AdminComponent } from './admin.component';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { By } from '@angular/platform-browser';

describe('AdminComponent', () => {
  let component: AdminComponent;
  let fixture: ComponentFixture<AdminComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [AdminComponent],
      imports: [
        RouterTestingModule,  // Importa RouterTestingModule para manejar routerLink
        MatButtonModule,      // Importa MatButtonModule para botones
        MatIconModule         // Importa MatIconModule para iconos
      ]
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AdminComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();  // Detecta cambios para renderizar el componente
  });

  it('debería crear el componente', () => {
    expect(component).toBeTruthy();
  });

  it('debería contener dos botones', () => {
    const buttons = fixture.debugElement.queryAll(By.css('button'));
    expect(buttons.length).toBe(2);  // Verifica que hay dos botones
  });

  it('el primer botón debería tener el texto "Usuarios"', () => {
    const firstButton = fixture.debugElement.query(By.css('.fab-button:first-child'));
    expect(firstButton.nativeElement.textContent).toContain('Usuarios');  // Verifica que el texto sea "Usuarios"
  });

  it('el segundo botón debería tener el texto "Roles"', () => {
    const secondButton = fixture.debugElement.query(By.css('.fab-button:last-child'));
    expect(secondButton.nativeElement.textContent).toContain('Roles');  // Verifica que el texto sea "Roles"
  });

  it('el primer botón debería tener el routerLink correcto', () => {
    const firstButton = fixture.debugElement.query(By.css('.fab-button:first-child'));
    expect(firstButton.nativeElement.getAttribute('ng-reflect-router-link')).toBe('/users');  // Verifica el routerLink
  });

  it('el segundo botón debería tener el routerLink correcto', () => {
    const secondButton = fixture.debugElement.query(By.css('.fab-button:last-child'));
    expect(secondButton.nativeElement.getAttribute('ng-reflect-router-link')).toBe('/user-groups');  // Verifica el routerLink
  });
});
