import { HttpClient } from '@angular/common/http';
import { Component, Inject } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { FormBuilder, FormGroup } from '@angular/forms';

@Component({
  selector: 'app-add-role-modal',
  templateUrl: './add-role-modal.component.html',
  styleUrls: ['./add-role-modal.component.css']
})
export class AddRoleModalComponent {
  roleForm: FormGroup;

  constructor(
    public dialogRef: MatDialogRef<AddRoleModalComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private http: HttpClient,
    private fb: FormBuilder
  ) {
    this.roleForm = this.fb.group({
      name: [''], 
      superAdmin: [false],
      orgAdmin: [false],
      orgOperator: [false],
      orgMinimal: [false],
      userRole: [false]
    });
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  onSubmit(): void {
    if (this.roleForm.valid) {
      const formValues = this.roleForm.value;

      const selectedPermissions: string[] = [];
      if (formValues.superAdmin) selectedPermissions.push('ROLE_SUPER_ADMIN');
      if (formValues.orgAdmin) selectedPermissions.push('ROLE_ORGANIZATIONAL_UNIT_ADMIN');
      if (formValues.orgOperator) selectedPermissions.push('ROLE_ORGANIZATIONAL_UNIT_OPERATOR');
      if (formValues.orgMinimal) selectedPermissions.push('ROLE_ORGANIZATIONAL_UNIT_MINIMAL');
      if (formValues.userRole) selectedPermissions.push('ROLE_USER');

      
      const payload = {
        name: formValues.name,
        permissions: selectedPermissions,
        enabled: true 
      };

      this.http.post('http://127.0.0.1:8001/user-groups', payload).subscribe(
        (response) => {
          this.dialogRef.close(); 
        },
        (error) => {
          console.error('Error al añadir rol', error);
        }
      );
    }
  }
}
