import { Component, OnInit } from '@angular/core';
import { RoleService } from './roles.service';
import { MatTableDataSource } from '@angular/material/table';
import { MatDialog } from '@angular/material/dialog';
import { AddRoleModalComponent } from './add-role-modal/add-role-modal.component';
import { DeleteModalComponent } from '../../../../shared/delete_modal/delete-modal/delete-modal.component';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-roles',
  templateUrl: './roles.component.html',
  styleUrls: ['./roles.component.css']
})
export class RolesComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  dataSource = new MatTableDataSource<any>();
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (role: any) => `${role.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre',
      cell: (role: any) => `${role.name}`
    },
    {
      columnDef: 'permissions',
      header: 'Permisos',
      cell: (role: any) => `${role.permissions.join(', ')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  constructor(private roleService: RoleService, public dialog: MatDialog, private http: HttpClient,
    private toastService: ToastrService) {}

  ngOnInit() {
    this.loadRoles();
  }

  loadRoles() {
    this.roleService.getRoles().subscribe(response => {
      console.log(response);
      this.dataSource.data = response['hydra:member'];
    });
  }

  addUser() {
    const dialogRef = this.dialog.open(AddRoleModalComponent);

    dialogRef.afterClosed().subscribe((result) => {
      this.loadRoles();
    });
  }

  deleteRole(role: any): void {
    const dialogRef = this.dialog.open(DeleteModalComponent, {
      width: '300px', 
      data: { name: role.name } 
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        const apiUrl = `${this.baseUrl}/user-groups/${role.uuid}`;
  
        this.http.delete(apiUrl).subscribe({
          next: () => {
            this.loadRoles(); 
            this.toastService.success('Role deleted successfully'); 
          },
          error: (error) => {
            this.toastService.error('Error deleting role:', error); 
          }
        });
      }
    });
  }
  
}
