import { Component, EventEmitter, Inject, OnInit, Output } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { UserService } from '../users.service';
import {ToastrService} from "ngx-toastr";

@Component({
  selector: 'app-edit-user-modal',
  templateUrl: './edit-user-modal.component.html',
  styleUrls: ['./edit-user-modal.component.css']
})
export class EditUserModalComponent implements OnInit {@Output() userEdited = new EventEmitter<void>();
  userForm: FormGroup;
  userGroups: any[] = [];
  organizationalUnits: any[] = [];
  loading:boolean = false;

  constructor(
    public dialogRef: MatDialogRef<EditUserModalComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private fb: FormBuilder,
    private userService: UserService, // Inyecta el servicio
    private toastService: ToastrService
  ) {
    this.userForm = this.fb.group({
      username: [this.data.user.username],
      password: [null],
      userGroups: [this.data.user.userGroups.map((group: { '@id': any; }) => group['@id'])],
      allowedOrganizationalUnits: [this.data.user.allowedOrganizationalUnits.map((unit: { '@id': any; }) => unit['@id'])]
    });
  }

  ngOnInit(): void {
    this.loading = true
    this.userService.getUserGroups().subscribe((data) => {
      this.userGroups = data['hydra:member'];
    });
    this.userService.getOrganizationalUnits().subscribe((data) => {
      this.organizationalUnits = data['hydra:member'].filter((item: any) => item.type === 'organizational-unit');
      this.loading = false
    }, (error) => {
      console.error('Error fetching organizational units', error);
      this.loading = false
    });
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  onSubmit(): void {
    console.log(this.userForm.value);
    const userPayload = {
      username: this.userForm.value.username,
      allowedOrganizationalUnits: this.userForm.value.allowedOrganizationalUnits,
      password: this.userForm.value.password,
      enabled: true,
      userGroups: this.userForm.value.userGroups
    };

    this.userService.updateUser(this.data.user.uuid, userPayload).subscribe(
      response => {
        console.log('User added successfully:', response);
        this.userEdited.emit();
        this.dialogRef.close(this.userForm.value);
        this.openSnackBar(false, 'Usuario actualizado correctamente')
      },
      error => {
        console.error('Error adding user:', error);
        this.openSnackBar(true, error.message);
        // Agregar alguna lógica para manejar el error en la interfaz de usuario
      }
    );
  }

  openSnackBar(isError: boolean, message: string) {
    if (isError) {
      this.toastService.error(' Error al eliminar la entidad: ' + message, 'Error');
    } else
      this.toastService.success(message, 'Éxito');
  }
}
