import { ComponentFixture, TestBed } from '@angular/core/testing';
import { UsersComponent } from './users.component';
import { MatTableModule } from '@angular/material/table';
import { MatDialogModule } from '@angular/material/dialog';
import { HttpClientTestingModule } from '@angular/common/http/testing';
import { ToastrService } from 'ngx-toastr';
import { of } from 'rxjs';
import { UserService } from './users.service';
import { NO_ERRORS_SCHEMA } from '@angular/core'; // Add this import for schema

// Create a mock for UserService
class MockUserService {
  getUsers() {
    return of({
      'hydra:member': [
        { id: 1, username: 'user1', allowedOrganizationalUnits: [], roles: ['admin'] },
        { id: 2, username: 'user2', allowedOrganizationalUnits: [], roles: ['user'] }
      ]
    });
  }
}

describe('UsersComponent', () => {
  let component: UsersComponent;
  let fixture: ComponentFixture<UsersComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [UsersComponent],
      imports: [
        MatTableModule,
        MatDialogModule,
        HttpClientTestingModule,
      ],
      providers: [
        { provide: UserService, useClass: MockUserService },
        { provide: ToastrService, useValue: { success: () => {} } }, // Mock ToastrService
      ],
      schemas: [NO_ERRORS_SCHEMA], // Use this to ignore unrecognized components in template
    })
    .compileComponents();
    
    fixture = TestBed.createComponent(UsersComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should load users on init', () => {
    component.ngOnInit();
    expect(component.dataSource.data.length).toBe(2); // Expect 2 mock users
  });
});
