import { Component, OnInit } from '@angular/core';
import { UserService } from './users.service';
import { MatTableDataSource } from '@angular/material/table';
import { MatDialog } from '@angular/material/dialog';
import { AddUserModalComponent } from './add-user-modal/add-user-modal.component';
import { EditUserModalComponent } from './edit-user-modal/edit-user-modal.component';
import { DeleteModalComponent } from '../../../../shared/delete_modal/delete-modal/delete-modal.component';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-users',
  templateUrl: './users.component.html',
  styleUrls: ['./users.component.css']
})

export class UsersComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  dataSource = new MatTableDataSource<any>();
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (user: any) => `${user.id}`
    },
    {
      columnDef: 'username',
      header: 'Nombre de Usuario',
      cell: (user: any) => `${user.username}`
    },
    {
      columnDef: 'allowedOrganizationalUnits',
      header: 'Unidades Organizacionales Permitidas',
      cell: (user: any) => `${user.allowedOrganizationalUnits.map((unit: { name: any; }) => unit.name).join(', ')}`
    },
    {
      columnDef: 'roles',
      header: 'Roles',
      cell: (user: any) => `${user.roles.join(', ')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  constructor(private userService: UserService, public dialog: MatDialog, 
    private http: HttpClient,
    private toastService: ToastrService) {}

  ngOnInit() {
    this.loadUsers();
  }

  loadUsers() {
    this.userService.getUsers().subscribe(response => {
      this.dataSource.data = response['hydra:member'];
    });
  }

  addUser() {
    const dialogRef = this.dialog.open(AddUserModalComponent, { width: '500px' });

    dialogRef.componentInstance.userAdded.subscribe(() => {
      this.loadUsers();
    });

  }

  editUser(user: any) {
    // Implementar la lógica de edición
    const dialogRef = this.dialog.open(EditUserModalComponent, {
      data: { user: user },
      width: '500px'
    });
    dialogRef.componentInstance.userEdited.subscribe(() => {
      this.loadUsers();
    });
  }

  deleteUser(user: any): void {
    const dialogRef = this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: user.name }
    });
  
    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        const apiUrl = `${this.baseUrl}/users/${user.uuid}`;
  
        this.http.delete(apiUrl).subscribe({
          next: () => {
            console.log('User deleted successfully');
            this.toastService.success('User deleted successfully');
            this.loadUsers();
          },
          error: (error) => {
            console.error('Error deleting user:', error);
          }
        });
      } else {
        console.log('User deletion cancelled');
      }
    });
  }
  
}
