import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs';

interface UserPayload {
  username: string;
  password: string;
  enabled: boolean;
  userGroups: string[];
  allowedOrganizationalUnits: any[];
}

interface ChangePasswordPayload {
  currentPassword: string;
  newPassword: string;
  repeatNewPassword: string;
}

interface UserGroup {
  '@id': string;
  name: string;
  role: string[];
}

@Injectable({
  providedIn: 'root'
})
export class UserService {
  private apiUrl = import.meta.env.NG_APP_BASE_API_URL;

  constructor(private http: HttpClient) {}

  addUser(userPayload: UserPayload): Observable<any> {
    const headers = new HttpHeaders({
      'Content-Type': 'application/ld+json',
    });
    return this.http.post(`${this.apiUrl}/users`, userPayload, { headers });
  }

  updateUser(userId: number, userPayload: UserPayload): Observable<any> {
    const headers = new HttpHeaders({
      'Content-Type': 'application/ld+json',
    });
    return this.http.put(`${this.apiUrl}/users/${userId}`, userPayload, { headers });
  }

  changePassword(userId: number, userPayload: ChangePasswordPayload): Observable<any> {
    const headers = new HttpHeaders({
      'Content-Type': 'application/ld+json',
    });
    return this.http.put(`${this.apiUrl}/users/${userId}/reset-password`, userPayload, { headers });
  }

  getUserGroups(): Observable<{ 'hydra:member': UserGroup[] }> {
    return this.http.get<{ 'hydra:member': UserGroup[] }>(`${this.apiUrl}/user-groups`);
  }

  getUsers(): Observable<any> {
    return this.http.get<any>(`${this.apiUrl}/users?page=1&itemsPerPage=30`);
  }

  getOrganizationalUnits(): Observable<any> {
    return this.http.get<any>(`${this.apiUrl}/organizational-units?page=1&itemsPerPage=10000`);

  }
}
