import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatDialogModule, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { CreateCalendarComponent } from './create-calendar.component';
import { ToastrService } from 'ngx-toastr';
import { HttpClientTestingModule } from '@angular/common/http/testing';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatIconModule } from '@angular/material/icon';
import { MatListModule } from '@angular/material/list';
import { MatDividerModule } from '@angular/material/divider';

// Mock para ToastrService
class MockToastrService {
  success(message: string) {}
  error(message: string) {}
}

// Mock para MatDialogRef
class MockMatDialogRef {
  close() {}
}

// Mock para ToastConfig
const mockToastConfig = {
  timeOut: 5000,
  positionClass: 'toast-top-right',
  preventDuplicates: true,
};

describe('CreateCalendarComponent', () => {
  let component: CreateCalendarComponent;
  let fixture: ComponentFixture<CreateCalendarComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        HttpClientTestingModule, // Importar el módulo de prueba de HttpClient
        MatDialogModule, // Importar MatDialogModule
        MatFormFieldModule, // Importar MatFormFieldModule
        MatInputModule, // Importar MatInputModule
        MatIconModule, // Importar MatIconModule
        MatListModule, // Importar MatListModule
        MatDividerModule // Importar MatDividerModule
      ],
      declarations: [CreateCalendarComponent],
      providers: [
        { provide: MatDialogRef, useClass: MockMatDialogRef },
        { provide: MAT_DIALOG_DATA, useValue: {} },
        { provide: ToastrService, useClass: MockToastrService },
        { provide: 'ToastConfig', useValue: mockToastConfig }, // Proveer el mock de ToastConfig
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(CreateCalendarComponent);
    component = fixture.componentInstance;
  });

  it('should create the component', () => {
    expect(component).toBeTruthy();
  });

  it('should initialize with default values', () => {
    component.ngOnInit();
    expect(component.isEditMode).toBeFalse();
    expect(component.name).toBe('');
  });

  it('should close the dialog on onNoClick', () => {
    const dialogRef = TestBed.inject(MatDialogRef);
    spyOn(dialogRef, 'close');
    
    component.onNoClick();
    
    expect(dialogRef.close).toHaveBeenCalled();
  });

  // Puedes agregar más pruebas según sea necesario
});
