import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';
import { CreateCommandGroupComponent } from './create-command-group/create-command-group.component'
import { DetailCommandGroupComponent } from './detail-command-group/detail-command-group.component';
import { DeleteModalComponent } from '../../../shared/delete_modal/delete-modal/delete-modal.component';

@Component({
  selector: 'app-commands-groups',
  templateUrl: './commands-groups.component.html',
  styleUrls: ['./commands-groups.component.css']
})
export class CommandsGroupsComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  commandGroups: any[] = [];
  filters: { [key: string]: string | boolean } = {};
  length: number = 0;
  itemsPerPage: number = 10;
  page: number = 1;
  pageSizeOptions: number[] = [5, 10, 20, 40, 100];
  displayedColumns: string[] = ['name', 'createdBy', 'createdAt', 'actions'];
  private apiUrl = `${this.baseUrl}/command-groups`;

  constructor(private http: HttpClient, private dialog: MatDialog, private toastService: ToastrService) {}

  ngOnInit(): void {
    this.search();
  }

  search(): void {
    this.http.get<any>(`${this.apiUrl}?page=${this.page}&itemsPerPage=${this.itemsPerPage}`, { params: this.filters }).subscribe(
      (data) => {
        this.commandGroups = data['hydra:member'];
        this.length = data['hydra:totalItems'];
      },
      (error) => {
        console.error('Error fetching command groups', error);
      }
    );
  }

  viewGroupDetails(group: any): void {
    this.dialog.open(DetailCommandGroupComponent, {
      width: '800px',
      data: group,
    }).afterClosed().subscribe(() => this.search());
  }

  openCreateCommandGroupModal(): void {
    this.dialog.open(CreateCommandGroupComponent, {
      width: '600px',
    }).afterClosed().subscribe(() => this.search());
  }

  editCommandGroup(group: any): void {
    this.dialog.open(CreateCommandGroupComponent, {
      width: '600px',
      data: { group },
    }).afterClosed().subscribe(() => this.search());
  }

  deleteCommandGroup(group: any): void {
    this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: group.name },
    }).afterClosed().subscribe((result) => {
      if (result) {
        this.http.delete(`${this.apiUrl}/${group.uuid}`).subscribe({
          next: () => {
            this.toastService.success('Grupo de comandos eliminado con éxito');
            this.search();
          },
          error: (error) => {
            console.error('Error al eliminar el grupo de comandos:', error);
          }
        });
      }
    });
  }

  onPageChange(event: any): void {
    this.page = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.search();
  }
}
