import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';

@Component({
  selector: 'app-task-logs',
  templateUrl: './task-logs.component.html',
  styleUrls: ['./task-logs.component.css']
})
export class TaskLogsComponent implements OnInit {

  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL; // Utilizando baseUrl desde el env
  traces: any[] = [];
  length: number = 0;
  itemsPerPage: number = 20;
  page: number = 1;
  pageSizeOptions: number[] = [10, 20, 30, 50];
  displayedColumns: string[] = ['commandName', 'clientName', 'status', 'executedAt', 'createdBy'];

  constructor(private http: HttpClient) {}

  ngOnInit(): void {
    this.loadTraces();
  }

  // Método para cargar las trazas con paginación
  loadTraces(): void {
    const url = `${this.baseUrl}/traces?page=${this.page}&itemsPerPage=${this.itemsPerPage}`;
    
    this.http.get<any>(url).subscribe(
      (data) => {
        this.traces = data['hydra:member'];
        this.length = data['hydra:totalItems'];
        console.log('Traces:', this.traces);
      },
      (error) => {
        console.error('Error fetching traces', error);
      }
    );
  }

  // Método que se llama cuando cambia la paginación
  onPageChange(event: any): void {
    this.page = event.pageIndex + 1; // Actualiza el número de página
    this.itemsPerPage = event.pageSize; // Actualiza los ítems por página
    this.loadTraces(); // Recarga las trazas con los nuevos parámetros de paginación
  }
}
