import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';
import { CommandDetailComponent } from './detail-command/command-detail.component';
import { CreateCommandComponent } from './create-command/create-command.component';
import { DeleteModalComponent } from '../../../shared/delete_modal/delete-modal/delete-modal.component';

@Component({
  selector: 'app-commands',
  templateUrl: './commands.component.html',
  styleUrls: ['./commands.component.css']
})
export class CommandsComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  commands: any[] = [];
  filters: { [key: string]: string | boolean } = {};
  length: number = 0;
  itemsPerPage: number = 20;
  page: number = 1;
  pageSizeOptions: number[] = [10, 20, 40, 100];
  displayedColumns: string[] = ['name', 'createdBy', 'createdAt', 'actions'];
  private apiUrl = `${this.baseUrl}/commands`;

  constructor(private http: HttpClient, private dialog: MatDialog, private toastService: ToastrService) {}

  ngOnInit(): void {
    this.search();
  }

  search(): void {
    this.http.get<any>(`${this.apiUrl}?page=${this.page}&itemsPerPage=${this.itemsPerPage}`, { params: this.filters }).subscribe(
      (data) => {
        this.commands = data['hydra:member'];
        this.length = data['hydra:totalItems'];
      },
      (error) => {
        console.error('Error fetching commands', error);
      }
    );
  }

  viewDetails(command: any): void {
    this.dialog.open(CommandDetailComponent, {
      width: '800px',
      data: command,
    }).afterClosed().subscribe(() => this.search());
  }

  openCreateCommandModal(): void {
    this.dialog.open(CreateCommandComponent, {
      width: '600px',
    }).afterClosed().subscribe(() => this.search());
  }

  editCommand(command: any): void {
    this.dialog.open(CreateCommandComponent, {
      width: '600px',
      data: { command },
    }).afterClosed().subscribe(() => this.search());
  }

  deleteCommand(command: any): void {
    this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: command.name },
    }).afterClosed().subscribe((result) => {
      if (result) {
        this.http.delete(`${this.apiUrl}/${command.uuid}`).subscribe({
          next: () => {
            this.toastService.success('Comando eliminado con éxito');
            this.search();
          },
          error: (error) => {
            console.error('Error al eliminar el comando:', error);
          }
        });
      }
    });
  }

  onPageChange(event: any): void {
    this.page = event.pageIndex === 0 ? 1 : event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.search();
  }
}
