import { Component, Inject, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialog, MatDialogRef } from '@angular/material/dialog';
import { CreateCommandComponent } from '../create-command/create-command.component';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-command-detail',
  templateUrl: './command-detail.component.html',
  styleUrls: ['./command-detail.component.css']
})
export class CommandDetailComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  form!: FormGroup;
  clients: any[] = [];
  showClientSelect = false;
  showDatePicker = false;
  canExecute = false;

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CommandDetailComponent>,
    private dialog: MatDialog,
    private toastService: ToastrService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) { }

  ngOnInit(): void {
    this.form = this.fb.group({
      selectedClients: [[this.data.importedClients], Validators.required],
      scheduleExecution: [false],
      scheduleDate: [''],
      scheduleTime: ['']
    });

    this.http.get<any>('http://127.0.0.1:8001/clients?page=1&itemsPerPage=30').subscribe(response => {
      this.clients = response['hydra:member'];
    });

  }

  execute(): void {
    if (!this.showClientSelect) {
      this.showClientSelect = true;
    } else {
      if (this.form.get('selectedClients')?.value.length > 0) {

        const payload = {
          clients: this.form.value.selectedClients.map((uuid: any) => `/clients/${uuid}`)
        };

        const apiUrl = `${this.baseUrl}/commands/${this.data.uuid}/execute`;
        this.http.post(apiUrl, payload).subscribe({
          next: () => {
            this.dialogRef.close();
            this.toastService.success('Command executed successfully');
          },
          error: (error) => {
            console.error('Error executing command:', error);
          }
        });

        this.dialogRef.close();
      } else {
        this.form.get('selectedClients')?.markAsTouched();
      }
    }
  }

  onClientSelectionChange(event: any): void {
    this.canExecute = this.form.get('selectedClients')?.value.length > 0;
  }

  onScheduleChange(event: any): void {
    this.showDatePicker = event.checked;
    if (event.checked) {
      this.form.get('scheduleDate')?.setValidators(Validators.required);
      this.form.get('scheduleTime')?.setValidators(Validators.required);
    } else {
      this.form.get('scheduleDate')?.clearValidators();
      this.form.get('scheduleTime')?.clearValidators();
    }
    this.form.get('scheduleDate')?.updateValueAndValidity();
    this.form.get('scheduleTime')?.updateValueAndValidity();
  }

  edit(): void {
    const dialogRef = this.dialog.open(CreateCommandComponent, {
      width: '600px',
      data: { command: this.data.command }
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.toastService.success('Comando editado' );
        this.data.command = result;
      }
    });
  }

  cancel(): void {
    this.dialogRef.close();
  }
}
