import { Injectable } from '@angular/core';
import {HttpClient, HttpParams} from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class DataService {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;

  private apiUrl = `${this.baseUrl}/organizational-units`;
  private clientsUrl = `${this.baseUrl}/clients`;

  constructor(private http: HttpClient) {}

  getClients(itemsPerPage: number = 10, page: number = 1): Observable<any> {
    return this.http.get<any>(this.clientsUrl, {
      params: new HttpParams().set('itemsPerPage', itemsPerPage.toString()).set('page', page.toString())
    })
      .pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member']
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching clients', error);
        return throwError(error);
      })
    );
  }
}
