import { ComponentFixture, TestBed } from '@angular/core/testing';
import { TreeViewComponent } from './tree-view.component';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { NestedTreeControl } from '@angular/cdk/tree';
import { MatTreeNestedDataSource } from '@angular/material/tree';

describe('TreeViewComponent', () => {
  let component: TreeViewComponent;
  let fixture: ComponentFixture<TreeViewComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [TreeViewComponent],
      providers: [
        { provide: MatDialogRef, useValue: { close: jasmine.createSpy('close') } },
        { provide: MAT_DIALOG_DATA, useValue: { data: {} } }
      ]
    }).compileComponents();

    fixture = TestBed.createComponent(TreeViewComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should initialize tree data correctly', () => {
    const mockData = {
      id: 1,
      name: 'Root',
      type: 'organizational-unit',
      clients: [],
      children: []
    };

    component.data = { data: mockData };
    component.ngOnInit();

    expect(component.dataSource.data).toEqual([mockData]);
  });

  it('should close the dialog', () => {
    // Using type assertion to access the private dialogRef
    (component as any).dialogRef.close(); // Cast to any to bypass TypeScript's private checks
    expect((component as any).dialogRef.close).toHaveBeenCalled(); // Again casting to any
  });

  it('should determine if a node has children or clients', () => {
    const nodeWithChildren: any = { children: [{ id: 2, name: 'Child', type: 'classroom' }], clients: [] };
    const nodeWithClients: any = { children: [], clients: [{ id: 1, name: 'Client 1', ip: '192.168.0.1', mac: '00:00:00:00:00:01' }] };
    const nodeWithoutChildrenOrClients: any = { children: [], clients: [] };

    expect(component.hasChild(0, nodeWithChildren)).toBeTrue();
    expect(component.hasChild(0, nodeWithClients)).toBeTrue();
    expect(component.hasChild(0, nodeWithoutChildrenOrClients)).toBeFalse();
  });
});
