import {Component, Inject, OnInit} from '@angular/core';
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {NestedTreeControl} from "@angular/cdk/tree";
import {MatTreeNestedDataSource} from "@angular/material/tree";

interface OrganizationalUnit {
  id: number;
  name: string;
  type: string;
  clients?: Client[];
  children?: OrganizationalUnit[];
}

interface Client {
  id: number;
  name: string;
  ip: string;
  mac: string;
  serialNumber: string;
}

@Component({
  selector: 'app-tree-view',
  templateUrl: './tree-view.component.html',
  styleUrl: './tree-view.component.css'
})
export class TreeViewComponent implements OnInit {
  treeControl = new NestedTreeControl<OrganizationalUnit>(node => node.children);
  dataSource = new MatTreeNestedDataSource<OrganizationalUnit>();

  constructor(
    private dialogRef: MatDialogRef<TreeViewComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
  }
  ngOnInit() {
    this.dataSource.data = [this.mapData(this.data.data)];
  }

  hasChild = (_: number, node: OrganizationalUnit) => (!!node.children && node.children.length > 0 || !!node.clients && node.clients.length > 0);

  private mapData(data: any): OrganizationalUnit {
    const mapClients = (clients: any[]): Client[] => {
      console.log(clients)
      return clients.map(client => ({
        id: client.id,
        name: client.name,
        ip: client.ip,
        mac: client.mac,
        serialNumber: client.serialNumber,
      }));
    };

    const mapChildren = (children: any[]): OrganizationalUnit[] => {
      return children.map(child => this.mapData(child));
    };

    return {
      id: data.id,
      name: data.name,
      type: data.type,
      clients: data.clients ? mapClients(data.clients) : [],
      children: data.children ? mapChildren(data.children) : []
    };
  }

  close(): void {
    this.dialogRef.close();
  }
}
