import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';

@Component({
  selector: 'app-add-clients-to-subnet',
  templateUrl: './add-clients-to-subnet.component.html',
  styleUrls: ['./add-clients-to-subnet.component.css']
})
export class AddClientsToSubnetComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  clients: any[] = [];
  selectedClients: any[] = [];
  loading: boolean = true;

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<AddClientsToSubnetComponent>,
    @Inject(MAT_DIALOG_DATA) public data: { subnetUuid: string, subnetName: string }  
     ) {}

  ngOnInit(): void {
    console.log('Selected subnet UUID:', this.data);
    this.loading = true;

    this.http.get<any>(`${this.baseUrl}/clients?page=1&itemsPerPage=30`).subscribe(
      response => {
        this.clients = response['hydra:member'];
        this.loading = false;
      },
      error => {
        console.error('Error fetching clients:', error);
        this.loading = false;
      }
    );
  }

  save() {
    const postData = {
      clients: JSON.stringify(this.selectedClients.map(client => client.uuid))  
    };

    this.http.post(`${this.baseUrl}/og-dhcp/server/${this.data.subnetUuid}/post-host`, postData).subscribe(
      response => {
        console.log('Clients assigned successfully:', response);
        this.dialogRef.close(this.selectedClients);
      },
      error => {
        console.error('Error assigning clients:', error);
      }
    );
  }

  close() {
    this.dialogRef.close();
  }
}
