import { ComponentFixture, TestBed } from '@angular/core/testing';
import { SidebarComponent } from './sidebar.component';
import { MatListModule } from '@angular/material/list';
import { MatIconModule } from '@angular/material/icon';
import { MatDialogModule } from '@angular/material/dialog';
import { MatDividerModule } from '@angular/material/divider';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';

describe('SidebarComponent', () => {
  let component: SidebarComponent;
  let fixture: ComponentFixture<SidebarComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [SidebarComponent],
      imports: [
        MatListModule,
        MatIconModule,
        MatDialogModule,
        MatDividerModule,
        BrowserAnimationsModule, // Necesario para que las animaciones de Angular Material funcionen bien en las pruebas.
      ],
      schemas: [CUSTOM_ELEMENTS_SCHEMA] // Para manejar cualquier elemento desconocido
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(SidebarComponent);
    component = fixture.componentInstance;
    fixture.detectChanges(); // Dibuja la vista inicial
  });

  it('should create the component', () => {
    expect(component).toBeTruthy(); // Verifica que el componente se creó correctamente.
  });

  it('should display the username correctly', () => {
    // Simula un token decodificado
    component.username = 'testUser';
    fixture.detectChanges();

    const compiled = fixture.nativeElement;
    expect(compiled.querySelector('.user-logged').textContent).toContain('testUser');
  });

  it('should toggle OgBoot submenu', () => {
    // Inicialmente, el submenú debe estar oculto
    expect(component.showOgBootSub).toBeFalse();

    // Llamar a la función de toggle
    component.toggleOgBootSub();
    expect(component.showOgBootSub).toBeTrue();

    // Llamar a la función de toggle otra vez
    component.toggleOgBootSub();
    expect(component.showOgBootSub).toBeFalse();
  });

  it('should toggle OgDhcp submenu', () => {
    // Inicialmente, el submenú debe estar oculto
    expect(component.showOgDhcpSub).toBeFalse();

    // Llamar a la función de toggle
    component.toggleOgDhcpSub();
    expect(component.showOgDhcpSub).toBeTrue();

    // Llamar a la función de toggle otra vez
    component.toggleOgDhcpSub();
    expect(component.showOgDhcpSub).toBeFalse();
  });

  it('should toggle Commands submenu', () => {
    // Inicialmente, el submenú debe estar oculto
    expect(component.showCommandSub).toBeFalse();

    // Llamar a la función de toggle
    component.toggleCommandSub();
    expect(component.showCommandSub).toBeTrue();

    // Llamar a la función de toggle otra vez
    component.toggleCommandSub();
    expect(component.showCommandSub).toBeFalse();
  });
});
